Tables and lists
================

In this section we give a tabular overview of all available prefixes, units and conversions in the code.

Unit prefixes
^^^^^^^^^^^^^

.. csv-table:: Unit prefixes
   :file: ../_static/tables/prefixes.csv
   :widths: 20 40 40
   :header-rows: 1

Base units
^^^^^^^^^^

.. csv-table:: Base units
   :file: ../_static/tables/unit_base.csv
   :widths: 20 40 40
   :header-rows: 1

Standard units
^^^^^^^^^^^^^^
		 
.. csv-table:: Standard units
   :file: ../_static/tables/unit_standard.csv
   :widths: 20 40 40 40
   :header-rows: 1


Physical constants
^^^^^^^^^^^^^^^^^^
		 
.. csv-table:: Physical constants
   :file: ../_static/tables/constants.csv
   :widths: 20 40 40
   :header-rows: 1
      
Logarithmic units
^^^^^^^^^^^^^^^^^

.. csv-table:: Logarithmic units
   :file: ../_static/tables/unit_logarithmic.csv
   :widths: 20 40 40
   :header-rows: 1

Temperature units
^^^^^^^^^^^^^^^^^

.. csv-table:: Temperature units
   :file: ../_static/tables/unit_temperature.csv
   :widths: 20 40 40
   :header-rows: 1

Unit systems
^^^^^^^^^^^^

.. csv-table:: Units of physical quantities in SI system
   :file: ../_static/tables/quantities_si.csv
   :widths: 20 42 20 40
   :header-rows: 1

.. csv-table:: Units of physical quantities in CGS system
   :file: ../_static/tables/quantities_cgs.csv
   :widths: 20 42 30
   :header-rows: 1

.. csv-table:: Units of physical quantities in AU system
   :file: ../_static/tables/quantities_au.csv
   :widths: 20 42 30
   :header-rows: 1
		 
